(h1:pre:overview)=
# Overview

A slightly more descriptive title for this module could be the following:
**Data-driven understanding of dielectric materials using methods and tools from materials informatics**.

```{figure} ../assets/fig/preamble/petousis_n_Eg.png
:alt: petousis_n_Eg
:width: 66%
:align: center

A log-log scatter plot of refractive index ($n$) vs. band gap ($E_g$) for materials from several crystal systems (adapted from Petousis, I. et al. {cite}`petousis_2017`).
```


## Description 

In order to solve several of the grand challenges of our time, we must engineer new, high-performing materials more rapidly than ever before. 
Naturally, this prompts several questions, including (but not limited to): 

- Which material properties are relevant for our problem? 
- How do we select the best materials? 
- How can we sustainably develop these materials? 

To help answer these questions, the field of **materials informatics** (MI) combines the power of data science and scientific computing with materials science domain knowledge to automatically identify patterns in materials data that can be exploited to guide materials design. 
With this interdisciplinary approach, scientists hope to programmatically aggregate all of our existing knowledge on materials and extract the salient features necessary to accelerate materials discovery and advance our scientific understanding.

````{margin}
```{admonition} Programming language
:class: hint
If you’re more comfortable with a different programming language (e.g., MATLAB, R), it’s 100% OK to use it for your research project, but we’ll still be running the tutorials in Python for a uniform, accessible experience.
```
````

In this module, you will conduct a short MI research project that is focused on using data-driven methods to improve our understanding of dielectric materials. 
We will hold interactive tutorials in Week 1 to introduce the key concepts in MI and ensure everyone is equipped with the main programmatic tools (_in Python_) to succeed. 
In Weeks 2 and 3, we’ll give you freedom to investigate a research question of interest to you, while still providing you with ample support and resources (and a few mini-lectures). 
In addition to gaining MI and programming knowledge, you will be strengthening your scientific communication skills, culminating in a short(!) final presentation to share what you learned from your research project. 
To highlight the broad impact of data-driven methods, we also plan to host a few guest talks from MI practitioners who will share their personal experiences working in this new and exciting field.



## Learning outcomes

By the end of this module, you will know how to:
- _Apply_ best practices when programmatically working with materials data (e.g., standardization, visualization, statistical analyses).
- _Communicate_ your own informatics research results and _evaluate_ those of others.
- _Evaluate_ the pros/cons and possibilities of materials informatics approaches.



## Who are we?   


````{margin} 
```{admonition} Contact
:class: tip

Enze can be reached at `chenze` at the Berkeley domain while Mark can be reached at `mdasta` at the same.
````

- [Mark Asta](https://mse.berkeley.edu/people_new/asta/) is a Professor of [Materials Science and Engineering](https://mse.berkeley.edu/) (MSE) at the [University of California, Berkeley](https://www.berkeley.edu/) (UCB) who leads a computational materials science [research group](https://asta.mse.berkeley.edu/).
He is also the Director of the [Materials Sciences Division](https://www2.lbl.gov/msd/) (MSD) at [Lawrence Berkeley National Laboratory](https://www.lbl.gov/) (LBL), and a proud 3× UCB alum!
- [Enze Chen](https://enze-chen.github.io/) is a 2nd-year MSE Ph.D. student in his group whose research uses atomistic simulations and MI to study the behavior of metal alloys.
He is a proud [Stanford University](https://www.stanford.edu/) alum, but enjoys life on this side of the Bay a lot more.


We both **love teaching**, and while you can think of us as "instructors" or "mentors," know that we're learning alongside you---_from_ all of you---as well.
What a joy.
Go Bears! 🐻


````{panels}
**Enze** 🐢
^^^
```{image} ../assets/fig/preamble/enze.jpg
:alt: enze
:height: 240px
:align: center
```

---

**Mark** 🚴‍♂️
^^^
```{image} ../assets/fig/preamble/mark.jpg
:alt: mark
:height: 240px
:align: center
```
````


## References

```{bibliography}
:style: unsrt
:filter: docname in docnames
```

